@@ -1,4 +1,4 @@
-/* SCCS  @(#)xval.c	1.8 12/13/99 */
+/* SCCS  @(#)xval.c	1.9 06/06/01 */
 /*
 ** Cross validate a model.  This routine is responsible for filling in
 **  two vectors -- xrisk = cross-validated risk estimate
@@ -27,6 +27,7 @@
 #include "rpartS.h"
 #include "rpartproto.h"
 
+#define DEBUG 0
 static int debug =0;    /*if it is odd, print out every tree */
                         /*if >= 2, print out every risk value we see */
 /* Next line only if mainline version */
@@ -45,7 +46,7 @@ void xval(int n_xval,  struct cptable *cptable_head,  Sint *x_grp,
     struct node *xtree;
     struct cptable *cplist;
     double temp;
-    double old_n, old_wt, total_wt;
+    double old_wt, total_wt;
     int *which;
 
     alphasave = rp.alpha;
@@ -68,7 +69,6 @@ void xval(int n_xval,  struct cptable *cptable_head,  Sint *x_grp,
 	cp[i] = sqrt(cplist->cp * (cplist->forward)->cp);
 	i++;
 	}
-    old_n =rp.n;
     total_wt =0;
     for (i=0; i<rp.n; i++) total_wt += rp.wt[i];
     old_wt = total_wt;
@@ -120,17 +120,21 @@ void xval(int n_xval,  struct cptable *cptable_head,  Sint *x_grp,
 	for (j=0; j<rp.n; j++) {
 	    if (which[j]==0) {
 		rundown(xtree, j, cp, xpred, xtemp);
+#if DEBUG > 1
 		if (debug >1) {
 		   jj = j+1;
 		   printf("\nObs %d, y=%f \n", jj, rp.ydata[j][0]);
-		   }
+		}
+#endif
 		/* add it in to the risk */
 		cplist = cptable_head;
 		for (jj = 0; jj<rp.num_unique_cp; jj++) {
 		    cplist->xrisk += xtemp[jj] * rp.wt[j];
 		    cplist->xstd  += xtemp[jj]*xtemp[jj] * rp.wt[j];
+#if DEBUG > 1
 		    if (debug>1) printf("  cp=%f, pred=%f, xtemp=%f\n",
-					  cp[jj]/old_wt, xpred[jj], xtemp[jj]);
+					cp[jj]/old_wt, xpred[jj], xtemp[jj]);
+#endif
 		    cplist = cplist->forward;
 		    }
 		}
